/** \file builtin.h
	Prototypes for functions for executing builtin functions.
*/


enum
{
	COMMAND_NOT_BUILTIN,
	BUILTIN_REGULAR,
	BUILTIN_ALIAS
}
;



/**
   Stringbuffer used to represent standard output
*/
extern string_buffer *sb_out;

/**
   Stringbuffer used to represent standard error
*/
extern string_buffer *sb_err;

/**
   Initialize builtin data. 
*/
void builtin_init();

/**
   Destroy builtin data.
*/
void builtin_destroy();

/**
  Is there a builtin command with the given name?
*/
int builtin_exists( wchar_t *cmd );

/**
  Execute a builtin or an alias with variables. 

  \param argv Array containing the command and parameters 
         of the builtin.  The list is terminated by a
         null pointer. This syntax resembles the syntax 
         for exec.
  \param type Type of builtin. Can be either 
         BUILTIN_REGULAR for a normal builtin, or 
         BUILTIN_ALIAS for an alias with variables.
*/
void builtin_exec( wchar_t **argv, int type );

/**
  Insert all builtin names into l. These are not copies of the strings and should not be freed after use.
*/
void builtin_get_names( array_list *list );

/**
   Pushes a new set of input/output to the stack. The new stdin is supplied, a new set of output string_buffers is created.
*/
void builtin_push_io( FILE *);

/**
   Pops a set of input/output from the stack. The output string_buffers are destroued, but the input file is not closed.
*/
void builtin_pop_io();
