/** \file history.h
  Prototypes for history functions, part of the user interface.
*/

/**
   Load history from file.
*/
void history_init();

/**
   Saves the new history to disc and frees all memory used by the history.
*/
void history_destroy();

/**
  Add a new history item to the bottom of the history, containing a
  copy of str. Remove any duplicates. Moves the current item past the
  end of the history list.
*/
void history_add( const wchar_t *str );

/**
  Find previous history item starting with str. If this moves before
  the start of the history, str is returned.
*/
const wchar_t *history_prev_match( const wchar_t *str );

/**
  Make current point to last hyistory item
*/
void history_reset();


/**
  Find next history item starting with str. If this moves past
  the end of the history, str is returned.  
*/
const wchar_t *history_next_match( const wchar_t *str);

/**
   Perform sanity checks
*/
void history_sanity_check();
