#
# This file defines various aliases for fish
#

#
# Make ls use colors if we are on a sytem that supports this
#
if ls --help 1>/dev/null 2>/dev/null
  alias ls "command ls --color=auto --indicator-style=classify"
end

#
# These are very common and useful
#
alias ll "ls -lh"
alias la "ls -lha"

#
# This allows us to use 'open FILENAME' to open a given file in the default 
# application for the file.
#
alias open "mimedb -l"

#
# Make pwd print out the home directory as a tilde.
#

alias pwd "if command pwd| grep \^$HOME >/dev/null; printf \~; command pwd |cut -b (echo $HOME|wc -c)-; else; command pwd; end;"

#
# Find a suitable browser for viewing the help pages.
# This is needed by the help alias defined below.
#

if test $BROWSER

	# User has manualy set a preferred browser, so we respect that
	set -g __FISH_BROWSER $BROWSER

else

	# Check for a text-based browser.
	for i in htmlview links elinks lynx w3m
		if which $i 2>/dev/null >/dev/null
			set -g __FISH_BROWSER $i
			break
  		end
	end

	# If we are in a graphical environment, we check if there is a
	# graphical browser to use instead.
	if test $DISPLAY
		for i in htmlview firefox mozilla konqueror epiphany opera netscape
			if which $i 2>/dev/null >/dev/null
				set -g __FISH_BROWSER $i
				break;
			end
		end
	end
end

#
# Find the location of the documentation.
#

for i in ~/doc/fish/ /usr/share/doc/fish/ 
	if test -d $i
		set -g __FISH_HELP_DIR $i;
		break;
	end
end

#
# help should use 'open' to find a suitable browser, but only 
# if there is a mime database _and_ DISPLAY is set, since the 
# browser will most likely be graphical. Since most systems which
# have a mime databe also have the htmlview program, this is mostly a
# theoretical problem.
#

alias -v help 'set __FISH_HELP_ITEM $1; set __FISH_HELP_PAGE index.html;  if test $__FISH_HELP_ITEM = .;     set __FISH_HELP_PAGE builtins.html\\\#source; end; if test $__FISH_HELP_ITEM = difference;    set __FISH_HELP_PAGE difference.html; end;if test $__FISH_HELP_ITEM = globbing;    set __FISH_HELP_PAGE index.html\\\#expand; end; for i in set cd eval exit read bg fg jobs while if for command builtin alias complete end else case switch break continue;    if test $i = $__FISH_HELP_ITEM;        set __FISH_HELP_PAGE builtins.html\\\#$i;    end;end;for i in syntax completion editor job-control todo bugs history killring help color prompt title expand variables builtin-overview;    if test $i = $__FISH_HELP_ITEM;        set __FISH_HELP_PAGE index.html\\\#$i;    end;end; eval $__FISH_BROWSER file://$__FISH_HELP_DIR$__FISH_HELP_PAGE;'

