/** \file reader.h 

    Prototypes for functions for reading data from stdin and passing
	to the parser. If stdin is a keyboard, it supplies a killring,
	history, syntax highlighting, tab-completion and various other
	features.
*/

/**
  Read commands from fd 0 until encountering EOF
*/
int reader_read();

/**
  Tell the shell that it should exit after the currently running command finishes.
*/
void do_exit();

/**
   Check that the reader is in a sane state
*/
void reader_sanity_check();

/**
   Returns the line number of the line that is currently parsed
*/
int reader_current_lineno();

/**
   Initialize the reader
*/
void reader_init();

/**
   Destroy and free resources used by the reader
*/
void reader_destroy();

/**
   Returns the filename of the file currently read
*/
wchar_t *reader_current_filename();

/**
   Push a new filename on the stack of read files
   
   \param fn The fileanme to push
*/
void reader_push_current_filename( wchar_t *fn );
/**
   Pop the current filename from the stack of read files
 */
wchar_t *reader_pop_current_filename();

/** 
	Returns the width of the terminal window, so that not all
	functions that use these values continually have to keep track of
	it.
*/
int reader_get_width();
/**
   Returns the height of the terminal window, so that not all
   functions that use these values continually have to keep track of
   it.
*/
int reader_get_height();

/**
   Write the title to the titlebar. This function is called just
   before a new application starts executing and just after it
   finishes.
*/
void reader_write_title();

/**
   Repaint the entire commandline. This means reset and clear the
   commandline, write the prompt, perform syntax highlighting, write
   the commandline and move the cursor.
*/
void repaint();

/**
  Run the specified command with the correct terminal modes, and while taking care to perform job notification, set the title, etc.
*/
void reader_run_command( wchar_t *buff );

/**
   Get the string of character currently entered into the command buffer
*/
wchar_t *reader_get_buffer();

/**
   Get the current cursor position in the command line
*/
int reader_get_cursor_pos();

/**
   Return the value of the interupted flag, which is set by the sigint handler, and clear it if it was set.
*/
int reader_interupted();


