#include "config.h"

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <termios.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>

#if HAVE_NCURSES_H
#include <ncurses.h>
#else
#include <curses.h>
#endif


#if HAVE_TERMIO_H
#include <termio.h>
#endif

#include <term.h>
#include <errno.h>

/*
  Small utility for setting the color.
  Usage: set_color COLOR
  where COLOR is either an integer from 0 to seven or one of the strings in the col array.
*/

#define COLORS (sizeof(col)/sizeof(char *))

char *col[]=
{
	"black",
	"red",
	"green",
	"brown",
	"yellow",
	"blue",
	"magenta",
	"purple",
	"cyan",
	"white",
	"normal"
}
;

int col_idx[]=
{
	0, 
	1,
	2,
	3,
	3,
	4,
	5,
	5,
	6,
	7,
	8
}
;


void print_help();


int main( int argc, char **argv )
{
	int color;
	char *endptr;


	if( argc != 2 )
	{
		print_help();
		return 1;
	}

	if( (strcmp( argv[1], "-h" )==0) || 
		((strncmp(argv[1],"--help", strlen(argv[1]))==0)&&(strlen(argv[1])>=3)) )
	{
		print_help();
		return 0;
	}
		
	if( (strcmp( argv[1], "-v" )==0) || 
		((strncmp(argv[1],"--version", strlen(argv[1]))==0)&&(strlen(argv[1])>=3)) )
	{
		printf( stderr, "set_color, version %s\n", PACKAGE_VERSION );
		return 0;
	}
		
	color = strtol( argv[1], &endptr, 10 );
	if(endptr<=argv[1])
	{
		int i;
		color = -1;
		for( i=0; i<COLORS; i++ )
		{
			
			if( strcasecmp( col[i], argv[1] ) == 0 )
			{
				color = col_idx[i];				
				break;
			}
		}
	}	

	if( color < 0 )
	{
		fprintf( stderr, "set_color: Unknown color %s\n", argv[1] );
		return 1;
	}	
	setupterm( 0, STDOUT_FILENO, 0);	
	if( color == 8 )
	{
		putp( tparm( set_a_foreground, 0) );
		putp( tparm(exit_attribute_mode) );		
	}	
	else
	{
		putp( tparm( set_a_foreground, color) );
	}
	del_curterm( cur_term );
}

